@@ -13,8 +13,11 @@
 #ifndef DOCUMENT_H
 #define DOCUMENT_H
 
+#include <glibmm.h>
+
 #include "BibData.h"
 
+class DocumentView;
 class Library;
 
 class Document {
@@ -24,13 +27,18 @@ class Document {
 	Glib::ustring key_;
 	std::vector<int> tagUids_;
 	Glib::RefPtr<Gdk::Pixbuf> thumbnail_;
+	static const Glib::ustring defaultKey_;
+	static Glib::RefPtr<Gdk::Pixbuf> loadingthumb_;
 
 	void setupThumbnail ();
+	DocumentView *view_;
 
 	BibData bib_;
 
 	public:
+	~Document ();
 	Document ();
+	Document (Document const & x);
 	Document (Glib::ustring const &filename);
 	Document (
 		Glib::ustring const &filename,
@@ -38,22 +46,25 @@ class Document {
 		Glib::ustring const &key,
 		std::vector<int> const &tagUids,
 		BibData const &bib);
-	Glib::ustring& getKey();
-	Glib::ustring& getFileName();
+	Glib::ustring const & getKey() const;
+	Glib::ustring const & getFileName() const;
 	// RelFileName is NOT kept up to date in general, it's
 	// used during loading and saving only
-	Glib::ustring& getRelFileName();
+	Glib::ustring const & getRelFileName() const;
 	void setFileName (Glib::ustring const &filename);
 	void updateRelFileName (Glib::ustring const &libfilename);
 	void setKey (Glib::ustring const &key);
-	Glib::RefPtr<Gdk::Pixbuf> getThumbnail () {return thumbnail_;}
+
 	std::vector<int>& getTags ();
 	void setTag (int uid);
 	void clearTag (int uid);
 	void clearTags ();
 
+	Glib::RefPtr<Gdk::Pixbuf> getThumbnail () {return thumbnail_;}
+	void setThumbnail (Glib::RefPtr<Gdk::Pixbuf> thumb);
+	void setView (DocumentView *view) {view_ = view;}
+
 	bool hasTag (int uid);
-	bool canWebLink ();
 	bool canGetMetadata ();
 	bool matchesSearch (Glib::ustring const &search);
 
@@ -63,17 +74,22 @@ class Document {
 		bool const usebraces,
 		bool const utf8);
 	void writeXML (std::ostringstream &out);
-	void readPDF ();
-	void getMetaData ();
+	bool readPDF ();
+	bool getMetaData ();
 	void renameFromKey ();
 
 	BibData& getBibData () {return bib_;}
 	void setBibData (BibData& bib){bib_ = bib;}
 
-	static Glib::RefPtr<Gdk::Pixbuf> defaultthumb_;
-	static Glib::RefPtr<Gdk::Pixbuf> thumbframe_;
-
 	Glib::ustring generateKey ();
+
+	bool parseBibtex (Glib::ustring const &bibtex);
+
+	void setField (Glib::ustring const &field, Glib::ustring const &value);
+	Glib::ustring getField (Glib::ustring const &field);
+	bool hasField (Glib::ustring const &field) const;
+	std::map <Glib::ustring, Glib::ustring> getFields ();
+	void clearFields ();
 };
 
 #endif
